# $Revision: 1.12 $, $Date: 2011/10/20 05:32:52 $
# TODO
# - Check for status of man pages http://code.google.com/p/redis/issues/detail?id=202
#
# Conditional build:
%if "%{pld_release}" == "ac"
%bcond_with		tests		# build without tests
%bcond_with		perftools	# google perftools
%else
%bcond_without	tests		# build without tests
%bcond_without	perftools	# google perftools
%endif

%ifnarch %{ix86} %{x8664} ppc
# available only on selected architectures
%undefine	with_perftools
%endif

Summary:	A persistent key-value database
Name:		redis
Version:	2.2.15
Release:	1
License:	BSD
Group:		Applications/Databases
URL:		http://www.redis.io/
Source0:	http://redis.googlecode.com/files/%{name}-%{version}.tar.gz
# Source0-md5:	e1b66f316f9276fe44f4cbd20b842c93
Source1:	%{name}.logrotate
Source2:	%{name}.init
Patch0:		%{name}.conf.patch
%{?with_perftools:BuildRequires:    google-perftools-devel}
BuildRequires:	rpm >= 4.4.9-56
BuildRequires:	rpmbuild(macros) >= 1.202
BuildRequires:	sed >= 4.0
%{?with_tests:BuildRequires:	tcl >= 8.5}
ExcludeArch:	sparc sparc64 alpha
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Redis is an advanced key-value store. It is similar to memcached but
the data set is not volatile, and values can be strings, exactly like
in memcached, but also lists, sets, and ordered sets. All this data
types can be manipulated with atomic operations to push/pop elements,
add/remove elements, perform server side union, intersection,
difference between sets, and so forth. Redis supports different kind
of sorting abilities.

%package server
Summary:	Persistent key-value database with network interface
Group:		Applications/Databases
Requires(post,preun):	/sbin/chkconfig
Requires(postun):	/usr/sbin/groupdel
Requires(postun):	/usr/sbin/userdel
Requires(pre):	/bin/id
Requires(pre):	/usr/bin/getgid
Requires(pre):	/usr/sbin/groupadd
Requires(pre):	/usr/sbin/useradd
Requires:	rc-scripts
Provides:	group(redis)
Provides:	user(redis)

%description server
Redis is a key-value database in a similar vein to memcache but the
dataset is non-volatile. Redis additionally provides native support
for atomically manipulating and querying data structures such as lists
and sets.

The dataset is stored entirely in memory and periodically flushed to
disk.

%package doc
Summary:	documentation for redis
Group:		Documentation

%description doc
HTML Documentation for Redis.

%prep
%setup -q
%patch0 -p1
# Remove integration tests
%{__sed} -i -e '/    execute_tests "integration\/replication"/d' tests/test_helper.tcl
%{__sed} -i -e '/    execute_tests "integration\/aof"/d' tests/test_helper.tcl

%build
%{__make} all \
	CC="%{__cc}" \
	CFLAGS="%{rpmcflags} -std=c99" \
	DEBUG="" \
%if %{with perftools}
	USE_TCMALLOC=yes \
%endif

%if %{with tests}
tclsh tests/test_helper.tcl
%endif

%install
rm -rf $RPM_BUILD_ROOT
%{__make} install \
	PREFIX=$RPM_BUILD_ROOT%{_prefix}

# Fix non-standard-executable-perm error
chmod a+x $RPM_BUILD_ROOT%{_bindir}/%{name}-*

# Ensure redis-server location doesn't change
install -d $RPM_BUILD_ROOT%{_sbindir}
mv $RPM_BUILD_ROOT%{_bindir}/%{name}-server $RPM_BUILD_ROOT%{_sbindir}/%{name}-server

# Install misc other
install -d $RPM_BUILD_ROOT/etc/{logrotate.d,rc.d/init.d}
install -p %{SOURCE1} $RPM_BUILD_ROOT/etc/logrotate.d/%{name}
install -p %{SOURCE2} $RPM_BUILD_ROOT/etc/rc.d/init.d/%{name}
install -p -D %{name}.conf $RPM_BUILD_ROOT%{_sysconfdir}/%{name}.conf
install -d $RPM_BUILD_ROOT%{_localstatedir}/{lib,log,run}/%{name}

%clean
rm -rf $RPM_BUILD_ROOT

%pre server
%groupadd -g 256 redis
%useradd -u 256 -g redis -d %{_sharedstatedir}/redis -s /sbin/nologin -c 'Redis Server' redis

%post server
/sbin/chkconfig --add redis
%service redis restart

%preun server
if [ "$1" = 0 ]; then
	%service redis stop
	/sbin/chkconfig --del redis
fi

%postun server
if [ "$1" = "0" ]; then
	%userremove redis
	%groupremove redis
fi

%files
%defattr(644,root,root,755)
%doc COPYING 00-RELEASENOTES BUGS Changelog README TODO
%attr(755,root,root) %{_bindir}/redis-benchmark
%attr(755,root,root) %{_bindir}/redis-check-aof
%attr(755,root,root) %{_bindir}/redis-check-dump
%attr(755,root,root) %{_bindir}/redis-cli

%files server
%defattr(644,root,root,755)
%config(noreplace) %{_sysconfdir}/%{name}.conf
%attr(754,root,root) /etc/rc.d/init.d/%{name}
%attr(755,root,root) %{_sbindir}/redis-server
%config(noreplace) /etc/logrotate.d/%{name}
%dir %attr(755,redis,root) %{_localstatedir}/lib/%{name}
%dir %attr(755,redis,root) %{_localstatedir}/log/%{name}
%dir %attr(755,redis,root) %{_localstatedir}/run/%{name}

%files doc
%defattr(644,root,root,755)
%doc doc/*

%define date	%(echo `LC_ALL="C" date +"%a %b %d %Y"`)
%changelog
* %{date} PLD Team <feedback@pld-linux.org>
All persons listed below can be reached at <cvs_login>@pld-linux.org

$Log: redis.spec,v $
Revision 1.12  2011/10/20 05:32:52  glen
- up to 2.2.15

Revision 1.11  2011/10/20 05:19:54  glen
- alpha broken, exclude

Revision 1.10  2011/10/14 04:04:31  glen
- update URL

Revision 1.9  2011/10/14 04:02:32  glen
- up to 2.2.14, with help of fedora spec

Revision 1.8  2011/02/06 16:50:41  sparky
- unified %clean section

Revision 1.7  2010/10/09 16:52:31  glen
- server has illegal instruction in sparc

Revision 1.6  2010/10/09 15:28:57  glen
- server subpackage

Revision 1.5  2010/10/09 15:15:07  glen
- doc subpackage
- tests need tcl 8.5

Revision 1.4  2010/10/09 15:08:01  glen
- release 1

Revision 1.3  2010/10/09 13:17:14  glen
- chkconfig, groups, etc

Revision 1.2  2010/10/09 13:13:47  glen
- registered uid/gid

Revision 1.1  2010/10/09 11:34:14  glen
- initial from https://bugzilla.redhat.com/show_bug.cgi?id=619237
  http://github.com/downloads/silas/rpms/redis-2.0.1-1.fc13.src.rpm
